# flake8: noqa

# import apis into api package
from petstore_client_test.api.pet_api import PetApi
from petstore_client_test.api.store_api import StoreApi
from petstore_client_test.api.user_api import UserApi




# coding: utf-8

# flake8: noqa

"""
    Swagger Petstore - OpenAPI 3.0

    This is a sample Pet Store Server based on the OpenAPI 3.0 specification.  You can find out more about Swagger at [http://swagger.io](http://swagger.io). In the third iteration of the pet store, we've switched to the design first approach! You can now help us improve the API whether it's by making changes to the definition itself or to the code. That way, with time, we can improve the API in general, and expose some of the new features in OAS3.  Some useful links: - [The Pet Store repository](https://github.com/swagger-api/swagger-petstore) - [The source API definition for the Pet Store](https://github.com/swagger-api/swagger-petstore/blob/master/src/main/resources/openapi.yaml)

    The version of the OpenAPI document: 1.0.19
    Contact: apiteam@swagger.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from petstore_client_test.api.pet_api import PetApi
from petstore_client_test.api.store_api import StoreApi
from petstore_client_test.api.user_api import UserApi

# import ApiClient
from petstore_client_test.api_response import ApiResponse
from petstore_client_test.api_client import ApiClient
from petstore_client_test.configuration import Configuration
from petstore_client_test.exceptions import OpenApiException
from petstore_client_test.exceptions import ApiTypeError
from petstore_client_test.exceptions import ApiValueError
from petstore_client_test.exceptions import ApiKeyError
from petstore_client_test.exceptions import ApiAttributeError
from petstore_client_test.exceptions import ApiException

# import models into sdk package
from petstore_client_test.models.address import Address
from petstore_client_test.models.api_response import ApiResponse
from petstore_client_test.models.category import Category
from petstore_client_test.models.customer import Customer
from petstore_client_test.models.order import Order
from petstore_client_test.models.pet import Pet
from petstore_client_test.models.tag import Tag
from petstore_client_test.models.user import User
